@@ -16,10 +16,9 @@ class TeamAPI(object):
     the team api
     """
     max_try = CxConfig.CxConfig.config.max_try
+    verify = CxConfig.CxConfig.config.verify
     teams = []
 
-    default_team_id = None
-
     def __init__(self):
         self.retry = 0
         self.get_all_teams()
@@ -41,7 +40,11 @@ class TeamAPI(object):
 
         teams_url = CxConfig.CxConfig.config.url + "/auth/teams"
 
-        r = requests.get(teams_url, headers=AuthenticationAPI.AuthenticationAPI.auth_headers)
+        r = requests.get(
+            url=teams_url,
+            headers=AuthenticationAPI.AuthenticationAPI.auth_headers,
+            verify=TeamAPI.verify
+        )
         if r.status_code == http.HTTPStatus.OK:
             a_list = r.json()
             teams = [
@@ -82,7 +85,6 @@ class TeamAPI(object):
         team_full_name_id_dict = {item.full_name: item.team_id for item in all_teams}
 
         team_id = team_full_name_id_dict.get(Path(team_full_name.replace("\\", "/")))
-        TeamAPI.default_team_id = team_id
 
         return team_id
 
